@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: fast-logger
-version: 2.4.1
-id: fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
-key: fastl_4Y7hJzyaWK4EQNfvf2ODm9
+version: 2.4.3
+id: fast-logger-2.4.3-07980efcfdf2821a6e4b588f1620bda1
+key: fastl_7BE9K8lRSSNFghT3GZfXYp
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: A fast logging system
@@ -15,13 +15,13 @@ exposed: True
 exposed-modules:
     System.Log.FastLogger System.Log.FastLogger.File
 hidden-modules: System.Log.FastLogger.IO
-                System.Log.FastLogger.IORef System.Log.FastLogger.LogStr
-                System.Log.FastLogger.Logger
+                System.Log.FastLogger.FileIO System.Log.FastLogger.IORef
+                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/fast-logger-2.4.1
-hs-libraries: HSfast-logger-2.4.1-4Y7hJzyaWK4EQNfvf2ODm9
+import-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/fast-logger-2.4.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/fast-logger-2.4.3
+hs-libraries: HSfast-logger-2.4.3-7BE9K8lRSSNFghT3GZfXYp
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
